/*
    Copyright (c) 2010, 2011 aizo ag, Zurich, Switzerland

    Author: Sergey 'Jin' Bostandzhyan <jin@dev.digitalstrom.org>

    This file is part of dS Assistant.

    dS-Assistant is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    dS-Assistant is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with digitalSTROM Server. If not, see <http://www.gnu.org/licenses/>.

    NOTE: all APIs, especially the JSON API, offered by this application
          are subject to change without further notice.
*/

#ifndef __DSA_WEB_HANDLERS_H__
#define __DSA_WEB_HANDLERS_H__

#include <string>

#include "mongoose/mongoose.h"
#include "util.h"

namespace dSA
{

class WebHandler
{
public:
    WebHandler(struct mg_connection* connection,
               const struct mg_request_info* request_info);
    virtual void process() = 0;
    virtual ~WebHandler();

protected:
    struct mg_connection* m_connection;
    const struct mg_request_info* m_request_info;
    webutil::query m_parameters;
    std::string m_command;

    /// \brief checks the specified string parameter, if empty sets default
    /// value, if non empty converts to int, throws exception in case the
    /// conversion to int fails.
    ///
    /// \param parameter string parameter that should be converted to int
    /// \param defaultValue if parameter string is empty, defaultValue will be
    ///                     returned
    /// \param name name of the parameter to be used in the error message
    int getOptionalIntParam(std::string parameter, int defaultValue,
                            std::string name);
    long long int getOptionalLLIntParam(std::string parameter,
                                        long long int defaultValue,
                                        std::string name);

};

}; // namespace

#endif//__DSA_WEB_HANDLERS_H__

